"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VotingService = void 0;
const LoggerFactory_1 = require("../logger/LoggerFactory");
const LogType_1 = require("../logger/LogType");
const BootstrapUtils_1 = require("./BootstrapUtils");
const path_1 = require("path");
const logger = LoggerFactory_1.default.getLogger(LogType_1.LogType.System);
class VotingService {
    constructor(params) {
        this.params = params;
    }
    async run(presetData, nodeAccount, nodePreset) {
        const symbolServerToolsImage = presetData.symbolServerToolsImage;
        if ((nodePreset === null || nodePreset === void 0 ? void 0 : nodePreset.voting) && nodeAccount.voting) {
            const privateKeyTreeFileName = 'private_key_tree1.dat';
            const dir = `${process.cwd()}/${this.params.target}`;
            const votingKeysFolder = `${dir}/data/${nodeAccount.name}/votingkeys`;
            const cmd = [
                '/usr/catapult/bin/catapult.tools.votingkey',
                `--secret=${nodeAccount.voting.privateKey}`,
                `--dilution=${presetData.votingKeyDilution}`,
                `--startEpoch=${presetData.votingKeyStartEpoch}`,
                `--endEpoch=${presetData.votingKeyEndEpoch}`,
                `--output=/votingKeys/${privateKeyTreeFileName}`,
            ];
            await BootstrapUtils_1.BootstrapUtils.mkdir(votingKeysFolder);
            await BootstrapUtils_1.BootstrapUtils.deleteFile(path_1.join(votingKeysFolder, privateKeyTreeFileName));
            const binds = [`${votingKeysFolder}:/votingKeys:rw`];
            const userId = await BootstrapUtils_1.BootstrapUtils.resolveDockerUserFromParam(this.params.user);
            const { stdout, stderr } = await BootstrapUtils_1.BootstrapUtils.runImageUsingExec({
                image: symbolServerToolsImage,
                userId: userId,
                cmds: cmd,
                binds: binds,
            });
            if (stdout.indexOf('<error> ') > -1) {
                logger.info(stdout);
                logger.error(stderr);
                throw new Error('Voting key failed. Check the logs!');
            }
            logger.info(`Voting key executed for node ${nodeAccount.name}!`);
        }
        else {
            logger.info(`Non-voting node ${nodeAccount.name}.`);
        }
    }
}
exports.VotingService = VotingService;
